pub fn code_pop_and_do(
push_state: &mut PushState,
_instruction_cache: &InstructionCache,
)Expand description
CODE.DO*: Like CODE.DO but pops the stack before, rather than after, the recursive execution.
pub fn code_pop_and_do(
push_state: &mut PushState,
_instruction_cache: &InstructionCache,
)CODE.DO*: Like CODE.DO but pops the stack before, rather than after, the recursive execution.