exec_cmd

Function exec_cmd 

pub fn exec_cmd(
    push_state: &mut PushState,
    _instruction_cache: &InstructionCache,
)
EXEC.CMD: Executes the top items of the name stack on the command line. The number of arguments n is specified by the top INTEGER item. The command is found at stack position n where the arguments are added in order of stack postion n-1…1.