pub fn input_available(
push_state: &mut PushState,
_instruction_cache: &InstructionCache,
)Expand description
INPUT.AVAILABLE: This instruction pushes true to the BOOLEAN stack if the input stack is not empty and false otherwise.
pub fn input_available(
push_state: &mut PushState,
_instruction_cache: &InstructionCache,
)INPUT.AVAILABLE: This instruction pushes true to the BOOLEAN stack if the input stack is not empty and false otherwise.