list_get

Function list_get 

pub fn list_get(
    push_state: &mut PushState,
    _instruction_cache: &InstructionCache,
)
LIST.GET: Pushes a copy of the items at the given stack position to the execution stack. The first element of the list (the id) is removed. The index i is taken from the top of the INTEGER stack and min-max corrected.