bool_vector_and

Function bool_vector_and 

pub fn bool_vector_and(
    push_state: &mut PushState,
    _instruction_cache: &InstructionCache,
)
BOOLVECTOR.AND: Pushes the result of applying element-wise AND of the top item to the second item on the BOOLVECTOR stack. It applies an offset to the indices of the top item. The offset is taken from the INTEGER stack. Indices that are outside of the valid range of the second item are ignored. If there is no overlap of indices the second item of the stack is pushed as a result.