bool_vector_or

Function bool_vector_or 

pub fn bool_vector_or(
    push_state: &mut PushState,
    _instruction_cache: &InstructionCache,
)
BOOLVECTOR.OR: Pushes the result of applying element-wise OR of the top item to the second item on the BOOLVECTOR stack. It applies an offset to the indices of the top item. The offset is taken from the INTEGER stack. Indices that are outside of the valid range of the second item are ignored. If there is no overlap of indices the second item of the stack is pushed as a result.