pub fn float_vector_divide(
push_state: &mut PushState,
_instruction_cache: &InstructionCache,
)Expand description
FLOATVECTOR./: Pushes the result of element-wise DIVIDE of the second item by the top item on the FLOATVECTOR stack. It applies an offset to the indices of the top item. The offset is taken from the INTEGER stack. Indices that are outside of the valid range of the second item are ignored. If there is no overlap of indices the second item of the stack is pushed as a result. If at least one divisor is zero the instruction acts as NOOP.