int_vector_add

Function int_vector_add 

pub fn int_vector_add(
    push_state: &mut PushState,
    _instruction_cache: &InstructionCache,
)
INTVECTOR.+: Pushes the result of applying element-wise ADD of the top item to the second item on the INTVECTOR stack. It applies an offset to the indices of the top item. The offset is taken from the INTEGER stack. Indices that are outside of the valid range of the second item are ignored. If there is no overlap of indices the second item of the stack is pushed as a result.