pub fn int_vector_loop(
push_state: &mut PushState,
_instruction_cache: &InstructionCache,
)Expand description
INTVECTOR.LOOP: Excecutes the top element of the EXEC stack once for each element of the top INTVECTOR item. The element that corresponds to the current loop iteration is pushed to the INTEGER stack.