pub fn int_vector_shove(
push_state: &mut PushState,
_instruction_cache: &InstructionCache,
)Expand description
INTVECTOR.SHOVE: Inserts the second INTEGER “deep” in the stack, at the position indexed by the top INTEGER. The index position is calculated after the index is removed.